@@ -78,8 +78,8 @@ def init_console_logging(package, verbosity_flag: int = 0):
         >>> args.verbosity_flag
         2
 
-        Now, init_console_logging with that verbosity_flag for YOUR package (replace "uologging" with the package that you want to trace):
-        >>> uologging.init_console_logging(uologging, args.verbosity_flag)
+        Now, init_console_logging with that verbosity_flag for YOUR package (replace 'mypackage' with the package that you want to trace):
+        >>> uologging.init_console_logging('mypackage', args.verbosity_flag)
     """
     _setup_console_logging(package)
     set_logging_verbosity(package, verbosity_flag)
